import { useState } from "react";
import "./App.css";
import { SolveigEditor } from "solveigmm-video-editor";

// Files hosted from the public folder
const baseUrl = process.env.PUBLIC_URL || '';

const EDITOR_JS_SRC = `${baseUrl}/editor/main.chunk.js`;
const EDITOR_CSS_SRC = `${baseUrl}/editor/main.css`;

const INITIAL_BACK_URL = localStorage.getItem('backUrl') || 'https://smarteditingonline.solveigmm.com/'

// In this example, we are using submittedUrl and submittedApi variables only for the form handling.
// You can change this approach
function App() {
  const [videoUrl, setVideoUrl] = useState(
    "https://smarteditingonline.solveigmm.com/files/test_video.mp4"
  );
  const [backUrl, setBackUrl] = useState(INITIAL_BACK_URL);
  const [submittedUrl, setSubmittedUrl] = useState("");
  const [submittedApi, setSubmittedApi] = useState(INITIAL_BACK_URL);

  const [showEditor, setShowEditor] = useState(true);

  const handleChangeShowEditor = (v) => {
    setShowEditor(v);
    localStorage.setItem("showEditor", v);
  };

  const handleRenderComplete = (data) => {
    alert(`Rendering completed. Callback url: ${data.detail.downloadUrl}`);
  };

  return (
    <div className="App">
      <header className="App-header">
        <div className="app-form-field">
          <span className="app-form-field-text">Backend API url:</span>
          <input
            className="edit-input-link"
            value={backUrl}
            onChange={(e) => setBackUrl(e.target.value)}
            placeholder="enter back url"
          />
          <button
            className="button-edit"
            onClick={() => {
              localStorage.setItem('backUrl', backUrl)
              setSubmittedApi(backUrl);
              setSubmittedUrl("");
              // Must reload page when change backend url (for reconnect websocket)
              setTimeout(() => {
                window.location.reload()
              }, 100)
            }}
            target="_blank"
            rel="noopener noreferrer"
          >
            Apply
          </button>
        </div>
        <div className="app-form-field">
          <span className="app-form-field-text">Input Media url:</span>
          <input
            className="edit-input-link"
            value={videoUrl}
            onChange={(e) => setVideoUrl(e.target.value)}
            placeholder="enter video url"
          />
        </div>
        <div className="editor-actions">
          <div className="app-form-field">
            <input
              id="showeditor"
              className="app-form-field-checkbox"
              type="checkbox"
              checked={showEditor}
              onChange={(e) => handleChangeShowEditor(e.target.checked)}
            />
            <label htmlFor="showeditor" className="app-form-field-text">
              Show editor
            </label>
          </div>
          <button
            className="button-edit"
            onClick={() => {
              setSubmittedUrl(videoUrl);
              // clear submittedUrl variable for importing twice from the same url
              setTimeout(() => {
                setSubmittedUrl('');
              })
            }}
            target="_blank"
            rel="noopener noreferrer"
          >
            Start editing
          </button>
        </div>
      </header>
      <SolveigEditor
        src={EDITOR_JS_SRC}
        css={EDITOR_CSS_SRC}
        width="100%"
        height="600px"
        hidden={!showEditor}
        videoUrl={submittedUrl}
        apiUrl={submittedApi}
        onVideoAdded={() => handleChangeShowEditor(true)}
        onRenderComplete={handleRenderComplete}
      />
    </div>
  );
}

export default App;
